@@ -28,7 +28,7 @@
 #include <QtGui/QColor>
 #include <QtCore/QObject>
 #include <QtCore/QVector>
-#include <QtGui/QFontMetrics>
+#include <QtGui/QFontMetricsF>
 #include <QStringListModel>
 
 class KConfigGroup;
@@ -221,12 +221,6 @@ class KATEPART_TESTS_EXPORT KateDocumentConfig : public KateConfig
     void setSmartHome (bool on);
     bool smartHome () const;
 
-    void setWrapCursor (bool on);
-    bool wrapCursor () const;
-
-    void setAutoBrackets (bool on);
-    bool autoBrackets () const;
-
     void setShowTabs (bool on);
     bool showTabs() const;
 
@@ -236,11 +230,14 @@ class KATEPART_TESTS_EXPORT KateDocumentConfig : public KateConfig
     void setReplaceTabsDyn (bool on);
     bool replaceTabsDyn() const;
 
-    void setRemoveTrailingDyn (bool on);
-    bool removeTrailingDyn() const;
-
-    void setRemoveSpaces (bool on);
-    bool removeSpaces () const;
+    /**
+     * Remove trailing spaces on save.
+     * triState = 0: never remove trailing spaces
+     * triState = 1: remove trailing spaces of modified lines (line modification system)
+     * triState = 2: remove trailing spaces in entire document
+     */
+    void setRemoveSpaces (int triState);
+    int removeSpaces () const;
 
     void setNewLineAtEof (bool on);
     bool newLineAtEof () const;
@@ -306,7 +303,7 @@ class KATEPART_TESTS_EXPORT KateDocumentConfig : public KateConfig
 
     bool onTheFlySpellCheck() const;
     void setOnTheFlySpellCheck(bool on);
-    
+
     int lineLengthLimit() const;
     void setLineLengthLimit(int limit);
 
@@ -348,20 +345,14 @@ class KATEPART_TESTS_EXPORT KateDocumentConfig : public KateConfig
     bool m_backspaceIndents : 1;
     bool m_smartHomeSet : 1;
     bool m_smartHome : 1;
-    bool m_wrapCursorSet : 1;
-    bool m_wrapCursor : 1;
-    bool m_autoBracketsSet : 1;
-    bool m_autoBrackets : 1;
     bool m_showTabsSet : 1;
     bool m_showTabs : 1;
     bool m_showSpacesSet : 1;
     bool m_showSpaces : 1;
     bool m_replaceTabsDynSet : 1;
     bool m_replaceTabsDyn : 1;
-    bool m_removeTrailingDynSet : 1;
-    bool m_removeTrailingDyn : 1;
     bool m_removeSpacesSet : 1;
-    bool m_removeSpaces : 1;
+    uint m_removeSpaces : 2;
     bool m_newLineAtEofSet : 1;
     bool m_newLineAtEof : 1;
     bool m_overwiteModeSet : 1;
@@ -442,6 +433,15 @@ class KATEPART_TESTS_EXPORT KateViewConfig : public KateConfig
     bool scrollBarMarks () const;
     void setScrollBarMarks (bool on);
 
+    bool scrollBarMiniMap () const;
+    void setScrollBarMiniMap (bool on);
+
+    bool scrollBarMiniMapAll () const;
+    void setScrollBarMiniMapAll (bool on);
+
+    int scrollBarMiniMapWidth () const;
+    void setScrollBarMiniMapWidth (int width);
+
     bool iconBar () const;
     void setIconBar (bool on);
 
@@ -482,7 +482,7 @@ class KATEPART_TESTS_EXPORT KateViewConfig : public KateConfig
 
     uint defaultMarkType () const;
     void setDefaultMarkType (uint type);
-    
+
     bool allowMarkMenu () const;
     void setAllowMarkMenu (bool allow);
 
@@ -529,6 +529,9 @@ class KATEPART_TESTS_EXPORT KateViewConfig : public KateConfig
     int m_dynWordWrapAlignIndent;
     bool m_lineNumbers;
     bool m_scrollBarMarks;
+    bool m_scrollBarMiniMap;
+    bool m_scrollBarMiniMapAll;
+    int  m_scrollBarMiniMapWidth;
     bool m_iconBar;
     bool m_foldingBar;
     bool m_lineModification;
@@ -554,6 +557,9 @@ class KATEPART_TESTS_EXPORT KateViewConfig : public KateConfig
     bool m_dynWordWrapAlignIndentSet : 1;
     bool m_lineNumbersSet : 1;
     bool m_scrollBarMarksSet : 1;
+    bool m_scrollBarMiniMapSet : 1;
+    bool m_scrollBarMiniMapAllSet : 1;
+    bool m_scrollBarMiniMapWidthSet : 1;
     bool m_iconBarSet : 1;
     bool m_foldingBarSet : 1;
     bool m_lineModificationSet : 1;
@@ -620,6 +626,7 @@ class KateRendererConfig : public KateConfig
   public:
     const QString &schema () const;
     void setSchema (const QString &schema);
+    
     /**
      * Reload the schema from the schema manager.
      * For the global instance, have all other instances reload.
@@ -628,7 +635,7 @@ class KateRendererConfig : public KateConfig
     void reloadSchema();
 
     const QFont& font() const;
-    const QFontMetrics& fontMetrics() const;
+    const QFontMetricsF& fontMetrics() const;
     void setFont(const QFont &font);
 
     bool wordWrapMarker () const;
@@ -664,11 +671,14 @@ class KateRendererConfig : public KateConfig
     const QColor& foldingColor() const;
     void setFoldingColor (const QColor &col);
 
-    // the line number color is used for the line numbers on the left bar and
-    // for vertical separator lines and for code folding lines.
+    // the line number color is used for the line numbers on the left bar
     const QColor& lineNumberColor() const;
     void setLineNumberColor (const QColor &col);
 
+    // the color of the separator between line numbers and icon bar
+    const QColor& separatorColor() const;
+    void setSeparatorColor(const QColor &col);
+
     const QColor& spellingMistakeLineColor() const;
     void setSpellingMistakeLineColor (const QColor &col);
 
@@ -703,7 +713,7 @@ class KateRendererConfig : public KateConfig
 
     QString m_schema;
     QFont m_font;
-    QFontMetrics m_fontMetrics;
+    QFontMetricsF m_fontMetrics;
     bool m_wordWrapMarker;
     bool m_showIndentationLines;
     bool m_showWholeBracketExpression;
@@ -717,6 +727,7 @@ class KateRendererConfig : public KateConfig
     QColor m_iconBarColor;
     QColor m_foldingColor;
     QColor m_lineNumberColor;
+    QColor m_separatorColor;
     QColor m_spellingMistakeLineColor;
     QVector<QColor> m_lineMarkerColor;
 
@@ -745,6 +756,7 @@ class KateRendererConfig : public KateConfig
     bool m_iconBarColorSet : 1;
     bool m_foldingColorSet : 1;
     bool m_lineNumberColorSet : 1;
+    bool m_separatorColorSet : 1;
     bool m_spellingMistakeLineColorSet : 1;
     bool m_templateColorsSet : 1;
     bool m_modifiedLineColorSet : 1;
