@@ -134,9 +134,32 @@ public:
   KateViReplaceMode* getViReplaceMode();
 
   /**
-   * @return true if running a macro
+   * @return true if running replaying the last change due to pressing "."
    */
-  bool isRunningMacro() const { return m_runningMacro; }
+  bool isReplayingLastChange() const { return m_replayingLastChange; }
+
+  /**
+   * set whether insert mode should be repeated as text instead of
+   * keystrokes. the default is keystrokes, which is reset between
+   * changes. for example, when invoking a completion command in
+   * insert mode, textual repeat should be enabled since repeating the
+   * completion may yield different results elsewhere in the document.
+   * therefore, it is better to repeat the text itself. however, most
+   * insertion commands do not need textual repeat; it should only be
+   * used when the repeating of keystrokes leads to unpredictable
+   * results. indeed, in most cases, repeating the keystrokes is the
+   * most predictable approach.
+   * @see isTextualRepeat()
+   * @return true if insert mode should be repeated as text
+   */
+  void setTextualRepeat( bool b = true ) { m_textualRepeat = b; }
+
+  /**
+   * whether insert mode should be repeated as text instead of keystrokes.
+   * @see setTextualRepeat()
+   * @return true if insert mode should be repeated as text
+   */
+  bool isTextualRepeat() const { return m_textualRepeat; }
 
   /**
    * append a QKeyEvent to the key event log
@@ -146,7 +169,7 @@ public:
   /**
    * clear the key event log
    */
-  void clearLog() { m_keyEventsLog.clear(); }
+  void clearLog() { m_keyEventsLog.clear(); m_keyEventsBeforeInsert.clear(); }
 
   /**
    * copy the contents of the key events log to m_lastChange so that it can be repeated
@@ -159,14 +182,18 @@ public:
   void repeatLastChange();
 
   /**
-   * get the last search term used
+   * The current search pattern.
+   * This is set by the last search.
+   * @return the search pattern or the empty string if not set
    */
-  const QString getLastSearchPattern() const { return m_lastSearchPattern; }
+  const QString getLastSearchPattern() const;
 
   /**
-   * record a search term so that it will be used with 'n' and 'N'
+   * Set the current search pattern.
+   * This is used by the "n" and "N" motions.
+   * @param p the search pattern
    */
-  void setLastSearchPattern( const QString &p ) { m_lastSearchPattern = p; }
+  void setLastSearchPattern( const QString &p );
 
   /**
    * get search direction of last search. (true if backwards, false if forwards)
@@ -184,7 +211,7 @@ public:
 
   void reset();
 
-  // Jup Lists
+  // Jump Lists
   void addJump(KTextEditor::Cursor cursor);
   KTextEditor::Cursor getNextJump(KTextEditor::Cursor cursor);
   KTextEditor::Cursor getPrevJump(KTextEditor::Cursor cursor);
@@ -195,7 +222,20 @@ public:
   void writeSessionConfig( KConfigGroup& config );
 
   // marks
-  void addMark( KateDocument* doc, const QChar& mark, const KTextEditor::Cursor& pos );
+  /**
+   * Add a mark to the document.
+   * By default, the mark is made visible in the document
+   * by highlighting its line, and it moves when inserting
+   * text at it.
+   * @param doc the document to insert the mark into
+   * @param mark the mark's name
+   * @param pos the mark's position
+   * @param moveoninsert whether the mark should move or stay behind
+   *        when inserting text at it
+   * @param showmark whether to highlight the mark's line
+   */
+  void addMark( KateDocument* doc, const QChar& mark, const KTextEditor::Cursor& pos,
+                const bool moveoninsert = true, const bool showmark = true );
   KTextEditor::Cursor getMarkPosition( const QChar& mark ) const;
   void syncViMarksAndBookmarks();
   QString getMarksOnTheLine(int line);
@@ -219,26 +259,32 @@ private:
   KateViKeyParser *m_keyParser;
 
   /**
-   * set to true when running a macro (including using the '.' command)
+   * set to true when replaying the last change (due to e.g. pressing ".")
    */
-  bool m_runningMacro;
+  bool m_replayingLastChange;
+
+  /**
+   * set to true when the insertion should be repeated as text
+   */
+  bool m_textualRepeat;
 
   /**
    * a continually updated list of the key events that was part of the last change.
-   * updated until it is copied to m_lastChange when change is completed.
+   * updated until copied to m_lastChange when the change is completed.
    */
   QList<QKeyEvent> m_keyEventsLog;
 
+  /**
+   * like m_keyEventsLog, but excludes insert mode: that is, only the key events
+   * leading up to insert mode (like "i", "cw", and "o") are logged.
+   */
+  QList<QKeyEvent> m_keyEventsBeforeInsert;
+
   /**
    * a list of the key events that was part of the last change.
    */
   QString m_lastChange;
 
-  /**
-   * the last pattern searched for
-   */
-  QString m_lastSearchPattern;
-
   /**
    * keeps track of whether the last search was done backwards or not.
    */
